from setuptools import setup, find_packages

setup(name='SHICTHRSTimer',
      version='1.2.0',
      description='SHICTHRS Timer time process system',
      url='https://github.com/JNTMTMTM/SHICTHRS_Timer',
      author='SHICTHRS',
      author_email='contact@shicthrs.com',
      license='GPL-3.0',
      packages=find_packages(),
      include_package_data=True,
      install_requires=['colorama==0.4.6' , 'pytz==2025.2'],
      zip_safe=False)
